@@ -1,7 +1,7 @@
 import requests
 
 SEND_MESSAGE_FORMAT = "https://api.telegram.org/bot{0}/sendmessage?chat_id={1}&text={2}"
-PIN_MESSAGE_FORMAT = "https://api.telegram.org/bot{0}/pinchatmessage?chat_id={1}&message_id={2}"
+PIN_MESSAGE_FORMAT = "https://api.telegram.org/bot{0}/pinchatmessage?chat_id={1}&message_id={2}&disable_web_page_preview=true"
 
 def send_message(bot_token, chat_id, chat_message):
     uri = SEND_MESSAGE_FORMAT.format(bot_token, chat_id, chat_message)
